..
   Copyright DB InfraGO AG and contributors
   SPDX-License-Identifier: Apache-2.0

*****************************
Welcome to the documentation!
*****************************

Python RailLabel Development-Kit
================================

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Black

**Date**: |today| **Version**: |Version|

Description
-----------
This library is designed to assist in the handling of the sensor annotations of Deutsche Bahn in the OpenLABEL data format. Common usage for the library:

* fetching specific information from annotation files
* filtering for specific frames, annotations or objects
* editing annotation files

If you want a quickstart at how to use this package, head right into the
:ref:`how-tos section <howtos>`.

.. toctree::
   :caption: Introduction
   :maxdepth: 4

   intro

.. toctree::
   :caption: Tutorials
   :titlesonly:

   howto

.. toctree::
   :caption: Modules
   :maxdepth: 4

   code/modules
